aboutsummaryrefslogtreecommitdiff
path: root/engines/gob/videoplayer.cpp
diff options
context:
space:
mode:
authorSven Hesse2011-01-22 11:39:03 +0000
committerSven Hesse2011-01-22 11:39:03 +0000
commit6e254c4f010a6b4f1ff49297e073d1ee59cafbb6 (patch)
tree2e218673ec39a2a800a269b819d8fa1a8dcab87e /engines/gob/videoplayer.cpp
parent86b90fe8a69868d1b28009e36730523652a69d17 (diff)
downloadscummvm-rg350-6e254c4f010a6b4f1ff49297e073d1ee59cafbb6.tar.gz
scummvm-rg350-6e254c4f010a6b4f1ff49297e073d1ee59cafbb6.tar.bz2
scummvm-rg350-6e254c4f010a6b4f1ff49297e073d1ee59cafbb6.zip
GOB: Actually, startFrame == -2 seems to be the only live video flag
svn-id: r55418
Diffstat (limited to 'engines/gob/videoplayer.cpp')
-rw-r--r--engines/gob/videoplayer.cpp18
1 files changed, 5 insertions, 13 deletions
diff --git a/engines/gob/videoplayer.cpp b/engines/gob/videoplayer.cpp
index 63d751b13e..f1876f5294 100644
--- a/engines/gob/videoplayer.cpp
+++ b/engines/gob/videoplayer.cpp
@@ -40,7 +40,7 @@ VideoPlayer::Properties::Properties() : type(kVideoTypeTry), sprite(Draw::kFront
x(-1), y(-1), width(-1), height(-1), flags(kFlagFrontSurface), switchColorMode(false),
startFrame(-1), lastFrame(-1), endFrame(-1), forceSeek(false),
breakKey(kShortKeyEscape), palCmd(8), palStart(0), palEnd(255), palFrame(-1),
- loop(false), fade(false), waitEndFrame(true), canceled(false) {
+ noBlock(false), loop(false), fade(false), waitEndFrame(true), canceled(false) {
}
@@ -74,7 +74,7 @@ VideoPlayer::~VideoPlayer() {
_videoSlots[i].close();
}
-void VideoPlayer::evaluateFlags(Properties &properties, bool allowNonBlock) {
+void VideoPlayer::evaluateFlags(Properties &properties) {
if (properties.flags & kFlagFrontSurface) {
properties.sprite = Draw::kFrontSurface;
} else if (properties.flags & kFlagOtherSurface) {
@@ -87,14 +87,6 @@ void VideoPlayer::evaluateFlags(Properties &properties, bool allowNonBlock) {
} else {
properties.sprite = Draw::kBackSurface;
}
-
- if (allowNonBlock) {
- if(!(properties.flags & 0x1000) && !(properties.flags & kFlagNoVideo))
- properties.flags |= kFlagNonBlocking;
- else
- properties.flags &= ~0x1000;
- } else
- properties.flags &= ~0x1000;
}
int VideoPlayer::openVideo(bool primary, const Common::String &file, Properties &properties) {
@@ -255,7 +247,7 @@ bool VideoPlayer::play(int slot, Properties &properties) {
properties.canceled = false;
- if (primary && (properties.flags & kFlagNonBlocking)) {
+ if (primary && properties.noBlock) {
video->live = true;
properties.waitEndFrame = false;
_liveProperties = properties;
@@ -263,9 +255,9 @@ bool VideoPlayer::play(int slot, Properties &properties) {
return true;
}
- if (_vm->getGameType() != kGameTypeUrban)
+ if ((_vm->getGameType() != kGameTypeUrban) && (_vm->getGameType() != kGameTypeBambou))
// NOTE: For testing (and comfort?) purposes, we enable aborting of all videos.
// Except for Urban Runner, where it leads to glitches
properties.breakKey = kShortKeyEscape;
while ((properties.startFrame != properties.lastFrame) &&
@@ -263,9 +255,9 @@ bool VideoPlayer::play(int slot, Properties &properties) {
// NOTE: For testing (and comfort?) purposes, we enable aborting of all videos.
- // Except for Urban Runner, where it leads to glitches
+ // Except for Urban Runner and Bambou, where it leads to glitches
properties.breakKey = kShortKeyEscape;
while ((properties.startFrame != properties.lastFrame) &&